@@ -34,6 +34,7 @@
 #include "rectmodel.h"
 #include "style.h"
 #include "table.h"
+#include "tablemodel.h"
 #include "text.h"
 #include "textmodel.h"
 #include "widget.h"
@@ -61,6 +62,7 @@ GType goo_canvas_rect_get_type(void);
 GType goo_canvas_rect_model_get_type(void);
 GType goo_canvas_style_get_type(void);
 GType goo_canvas_table_get_type(void);
+GType goo_canvas_table_model_get_type(void);
 GType goo_canvas_text_get_type(void);
 GType goo_canvas_text_model_get_type(void);
 GType goo_canvas_widget_get_type(void);
@@ -89,6 +91,7 @@ namespace Goocanvas {  class Rect_Class { public: static Glib::ObjectBase* wrap_
 namespace Goocanvas {  class RectModel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Goocanvas {  class Style_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Goocanvas {  class Table_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Goocanvas {  class TableModel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Goocanvas {  class Text_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Goocanvas {  class TextModel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Goocanvas {  class Widget_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -117,6 +120,7 @@ void wrap_init()
   Glib::wrap_register(goo_canvas_rect_model_get_type(), &Goocanvas::RectModel_Class::wrap_new);
   Glib::wrap_register(goo_canvas_style_get_type(), &Goocanvas::Style_Class::wrap_new);
   Glib::wrap_register(goo_canvas_table_get_type(), &Goocanvas::Table_Class::wrap_new);
+  Glib::wrap_register(goo_canvas_table_model_get_type(), &Goocanvas::TableModel_Class::wrap_new);
   Glib::wrap_register(goo_canvas_text_get_type(), &Goocanvas::Text_Class::wrap_new);
   Glib::wrap_register(goo_canvas_text_model_get_type(), &Goocanvas::TextModel_Class::wrap_new);
   Glib::wrap_register(goo_canvas_widget_get_type(), &Goocanvas::Widget_Class::wrap_new);
@@ -139,6 +143,7 @@ void wrap_init()
   Goocanvas::RectModel::get_type();
   Goocanvas::Style::get_type();
   Goocanvas::Table::get_type();
+  Goocanvas::TableModel::get_type();
   Goocanvas::Text::get_type();
   Goocanvas::TextModel::get_type();
   Goocanvas::Widget::get_type();
